<?xml version="1.0"?>
<app>


<category>
Screencast
</category>

<name>
OBS-Studio
</name>

<description>
   <am>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</am>
   <ar>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</ar>
   <be>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</be>
   <bg>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</bg>
   <bn>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</bn>
   <ca>OBS-Studio - Streaming Video i Screencaster (cal maquinari OpenGL 3)</ca>
   <cs>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</cs>
   <da>OBS-Studio - Streaming af video og skærmudsendelse (kræver OpenGL 3-hardware)</da>
   <de>OBS-Studio - Streaming Video und Screencaster (OpenGL 3 Hardware erforderlich)</de>
   <el>OBS-Studio - Video Streaming και Screencaster (Απαιτείται hardware με OpenGL 3)</el>
   <en>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</en>
   <es_ES>OBS-Studio - Transmisión de Video y Screencaster (requiere hardware OpenGL 3)</es_ES>
   <es>OBS-Studio - Transmisión de Video y Screencaster (requiere hardware OpenGL 3)</es>
   <et>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</et>
   <eu>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</eu>
   <fa>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</fa>
   <fil_PH>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</fil_PH>
   <fi>OBS-Studio - striimaa videota ja toteuta ohjelmalähetyksiä (vaatii OpenGL 3 laitteiston)</fi>
   <fr_BE>OBS-Studio - Diffusion vidéo et capture vidéo d'écran (support OpenGL 3 nécessaire)</fr_BE>
   <fr>OBS-Studio - Diffusion vidéo et capture vidéo d'écran (support OpenGL 3 nécessaire)</fr>
   <gl_ES>OBS-Studio - Visualización de vídeos de internet e creación de vídeos da pantalla (require equipamento OpenGL 3)</gl_ES>
   <gu>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</gu>
   <he_IL>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</he_IL>
   <hi>ओबीएस स्टूडियो - वीडियो व स्क्रीन सहभाजन स्ट्रीम साधन (ओपेन जीएल 3 हार्डवेयर आवश्यक)</hi>
   <hr>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</hr>
   <hu>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</hu>
   <id>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</id>
   <is>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</is>
   <it>OBS-Studio - Strumento di registrazione e streaming di contenuti video (è richiesto hardware OpenGL 3)</it>
   <ja>OBS-Studio - ストリーミングビデオおよびスクリーンキャスター（OpenGL 3 ハードウェアが必要です）</ja>
   <kk>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</kk>
   <ko>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</ko>
   <lt>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</lt>
   <mk>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</mk>
   <mr>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</mr>
   <nb_NO>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</nb_NO>
   <nb>OBS-Studio – videostrømming og skjermkringkasting (OpenGL 3-maskinvare påkrevd)</nb>
   <nl_BE>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</nl_BE>
   <nl>OBS-Studio - Video en Screencaster Streamen (OpenGL 3 hardware vereist)</nl>
   <pl>strumieniowanie wideo i nagrywanie ekranu komputera (wymagany sprzęt OpenGL 3)</pl>
   <pt_BR>OBS-Studio - Visualização de vídeos da internet e criação de vídeos da tela da área de trabalho (requer equipamento OpenGL 3)</pt_BR>
   <pt>OBS-Studio - Visualização de vídeos da internet e criação de vídeos do ecrã (requer equipamento OpenGL 3)</pt>
   <ro>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</ro>
   <ru>Потоковое видео и видеотрансляции экрана (требуется OpenGL 3 оборудование)</ru>
   <sk>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</sk>
   <sl>OBS-Studio - program za pretakanje videa in vsebine zaslona (potrebna je OpenGL 3 strojna oprema)</sl>
   <sq>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</sq>
   <sr>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</sr>
   <sv>OBS-Studio - Strömmande Video och Skärminspelare (OpenGL 3 hårdvara krävs)</sv>
   <th>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</th>
   <tr>OBS-Studio - Video Akışı ve Hareketli Ekran Görüntüsü yapıcı (OpenGL 3 donanım gerekir)</tr>
   <uk>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</uk>
   <vi>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</vi>
   <zh_CN>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</zh_CN>
   <zh_HK>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</zh_HK>
   <zh_TW>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/014/886/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
obs-studio
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
obs-studio
</uninstall_package_names>

</app>
